from __future__ import annotations

# --8<-- [start:example]
# project/
# ├── celeryconfig.py       # Celery configuration
# ├── tasks.py              # Task definitions
# ├── submit.py             # Client that submits jobs
# ├── models/               # EnergyPlus IDF/epJSON files
# │   └── office.idf
# └── weather/              # Weather files
#     └── chicago.epw
# --8<-- [end:example]
